==> gorilla-notes-0.4.0.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$players$Twitch.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_player$lib$players$Twitch=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:
{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=
!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=exports.Twitch=void 0;var _react=
function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,
key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_utils=require("module$node_modules$react_player$lib$utils");global=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$singlePlayer"));var MATCH_VIDEO_URL=/(?:www\.|go\.)?twitch\.tv\/videos\/(\d+)($|\?)/,MATCH_CHANNEL_URL=/(?:www\.|go\.)?twitch\.tv\/([a-z0-9_]+)($|\?)/;require=function(_Component){function Twitch$jscomp$0(){if(!(this instanceof
Twitch$jscomp$0))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"callPlayer",_utils.callPlayer);_defineProperty(_assertThisInitialized(_this),"playerID",_this.props.config.twitch.playerId||"".concat("twitch-player-").concat((0,_utils.randomString)()));_defineProperty(_assertThisInitialized(_this),
"mute",function(){_this.callPlayer("setMuted",!0)});_defineProperty(_assertThisInitialized(_this),"unmute",function(){_this.callPlayer("setMuted",!1)});return _this}_inherits(Twitch$jscomp$0,_Component);var _super=_createSuper(Twitch$jscomp$0);_createClass(Twitch$jscomp$0,[{key:"load",value:function(url,isReady){var _this2=this,_this$props=this.props,playsinline=_this$props.playsinline,onError=_this$props.onError,config=_this$props.config,controls=_this$props.controls,isChannel=MATCH_CHANNEL_URL.test(url),
id=isChannel?url.match(MATCH_CHANNEL_URL)[1]:url.match(MATCH_VIDEO_URL)[1];isReady?isChannel?this.player.setChannel(id):this.player.setVideo("v"+id):(0,_utils.getSDK)("https://player.twitch.tv/js/embed/v1.js","Twitch").then(function(Twitch){_this2.player=new Twitch.Player(_this2.playerID,_objectSpread({video:isChannel?"":id,channel:isChannel?id:"",height:"100%",width:"100%",playsinline,autoplay:_this2.props.playing,muted:_this2.props.muted,controls:isChannel?!0:controls},config.twitch.options));Twitch=
Twitch.Player;var PLAYING=Twitch.PLAYING,PAUSE=Twitch.PAUSE,ENDED=Twitch.ENDED,ONLINE=Twitch.ONLINE,OFFLINE=Twitch.OFFLINE;_this2.player.addEventListener(Twitch.READY,_this2.props.onReady);_this2.player.addEventListener(PLAYING,_this2.props.onPlay);_this2.player.addEventListener(PAUSE,_this2.props.onPause);_this2.player.addEventListener(ENDED,_this2.props.onEnded);_this2.player.addEventListener(ONLINE,_this2.props.onLoaded);_this2.player.addEventListener(OFFLINE,_this2.props.onLoaded)},onError)}},
{key:"play",value:function(){this.callPlayer("play")}},{key:"pause",value:function(){this.callPlayer("pause")}},{key:"stop",value:function(){this.callPlayer("pause")}},{key:"seekTo",value:function(seconds){this.callPlayer("seek",seconds)}},{key:"setVolume",value:function(fraction){this.callPlayer("setVolume",fraction)}},{key:"getDuration",value:function(){return this.callPlayer("getDuration")}},{key:"getCurrentTime",value:function(){return this.callPlayer("getCurrentTime")}},{key:"getSecondsLoaded",
value:function(){return null}},{key:"render",value:function(){return _react["default"].createElement("div",{style:{width:"100%",height:"100%"},id:this.playerID})}}]);return Twitch$jscomp$0}(_react.Component);exports.Twitch=require;_defineProperty(require,"displayName","Twitch");_defineProperty(require,"canPlay",function(url){return MATCH_VIDEO_URL.test(url)||MATCH_CHANNEL_URL.test(url)});_defineProperty(require,"loopOnEnded",!0);global=(0,global["default"])(require);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$players$Twitch.js.map

==> gorilla-notes-0.5.7.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$players$Twitch.js <==
shadow$provide.module$node_modules$react_player$lib$players$Twitch=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:
{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=
!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=exports.Twitch=void 0;var _react=
function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,
key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_utils=require("module$node_modules$react_player$lib$utils");global=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$singlePlayer"));var MATCH_VIDEO_URL=/(?:www\.|go\.)?twitch\.tv\/videos\/(\d+)($|\?)/,MATCH_CHANNEL_URL=/(?:www\.|go\.)?twitch\.tv\/([a-z0-9_]+)($|\?)/;require=function(_Component){function Twitch$jscomp$0(){if(!(this instanceof
Twitch$jscomp$0))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"callPlayer",_utils.callPlayer);_defineProperty(_assertThisInitialized(_this),"playerID",_this.props.config.twitch.playerId||"".concat("twitch-player-").concat((0,_utils.randomString)()));_defineProperty(_assertThisInitialized(_this),
"mute",function(){_this.callPlayer("setMuted",!0)});_defineProperty(_assertThisInitialized(_this),"unmute",function(){_this.callPlayer("setMuted",!1)});return _this}_inherits(Twitch$jscomp$0,_Component);var _super=_createSuper(Twitch$jscomp$0);_createClass(Twitch$jscomp$0,[{key:"load",value:function(url,isReady){var _this2=this,_this$props=this.props,playsinline=_this$props.playsinline,onError=_this$props.onError,config=_this$props.config,controls=_this$props.controls,isChannel=MATCH_CHANNEL_URL.test(url),
id=isChannel?url.match(MATCH_CHANNEL_URL)[1]:url.match(MATCH_VIDEO_URL)[1];isReady?isChannel?this.player.setChannel(id):this.player.setVideo("v"+id):(0,_utils.getSDK)("https://player.twitch.tv/js/embed/v1.js","Twitch").then(function(Twitch){_this2.player=new Twitch.Player(_this2.playerID,_objectSpread({video:isChannel?"":id,channel:isChannel?id:"",height:"100%",width:"100%",playsinline:playsinline,autoplay:_this2.props.playing,muted:_this2.props.muted,controls:isChannel?!0:controls},config.twitch.options));
Twitch=Twitch.Player;var PLAYING=Twitch.PLAYING,PAUSE=Twitch.PAUSE,ENDED=Twitch.ENDED,ONLINE=Twitch.ONLINE,OFFLINE=Twitch.OFFLINE;_this2.player.addEventListener(Twitch.READY,_this2.props.onReady);_this2.player.addEventListener(PLAYING,_this2.props.onPlay);_this2.player.addEventListener(PAUSE,_this2.props.onPause);_this2.player.addEventListener(ENDED,_this2.props.onEnded);_this2.player.addEventListener(ONLINE,_this2.props.onLoaded);_this2.player.addEventListener(OFFLINE,_this2.props.onLoaded)},onError)}},
{key:"play",value:function(){this.callPlayer("play")}},{key:"pause",value:function(){this.callPlayer("pause")}},{key:"stop",value:function(){this.callPlayer("pause")}},{key:"seekTo",value:function(seconds){this.callPlayer("seek",seconds)}},{key:"setVolume",value:function(fraction){this.callPlayer("setVolume",fraction)}},{key:"getDuration",value:function(){return this.callPlayer("getDuration")}},{key:"getCurrentTime",value:function(){return this.callPlayer("getCurrentTime")}},{key:"getSecondsLoaded",
value:function(){return null}},{key:"render",value:function(){return _react["default"].createElement("div",{style:{width:"100%",height:"100%"},id:this.playerID})}}]);return Twitch$jscomp$0}(_react.Component);exports.Twitch=require;_defineProperty(require,"displayName","Twitch");_defineProperty(require,"canPlay",function(url){return MATCH_VIDEO_URL.test(url)||MATCH_CHANNEL_URL.test(url)});_defineProperty(require,"loopOnEnded",!0);global=(0,global["default"])(require);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$players$Twitch.js.map
